@@ -1,8 +1,7 @@
-package Dist::Zilla::Plugin::PodPurler;
-{
-  $Dist::Zilla::Plugin::PodPurler::VERSION = '0.093401';
-}
+package Dist::Zilla::Plugin::PodPurler 0.094;
 # ABSTRACT: like PodWeaver, but more erratic and amateurish
+
+use v5.20.0;
 use Moose;
 use Moose::Autobox 0.08;
 use List::MoreUtils qw(any);
@@ -16,6 +15,18 @@ use Pod::Elemental::Transformer::Pod5;
 use Pod::Elemental::Transformer::Nester;
 use Pod::Elemental::Transformer::Gatherer;
 
+#pod =head1 WARNING
+#pod
+#pod This library has been superceded by L<Pod::Weaver> and
+#pod L<Dist::Zilla::Plugin::PodWeaver>.  It is unlikely to be updated again unless
+#pod there are serious security problems (!?) or someone gives me some money.
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod PodPurler ress, which rips apart your kinda-POD and reconstructs it as boring
+#pod old real POD.
+#pod
+#pod =cut
 
 sub munge_file {
   my ($self, $file) = @_;
@@ -181,19 +192,28 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PodPurler - like PodWeaver, but more erratic and amateurish
 
 =head1 VERSION
 
-version 0.093401
+version 0.094
 
 =head1 DESCRIPTION
 
 PodPurler ress, which rips apart your kinda-POD and reconstructs it as boring
 old real POD.
 
+=head1 PERL VERSION SUPPORT
+
+This code is effectively abandonware.  Although releases will sometimes be made
+to update contact info or to fix packaging flaws, bug reports will mostly be
+ignored.  Feature requests are even more likely to be ignored.  (If someone
+takes up maintenance of this code, they will presumably remove this notice.)
+
 =head1 WARNING
 
 This library has been superceded by L<Pod::Weaver> and
@@ -202,11 +222,11 @@ there are serious security problems (!?) or someone gives me some money.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
